@@ -6,7 +6,7 @@ use DBI;
 use File::Slurp;
 use File::Spec;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 __PACKAGE__->mk_accessors(qw/debug dir dsn password username/);
 
@@ -170,12 +170,12 @@ sub _create_migration_table {
     my $self = shift;
     $self->{_dbh}->do(<<"EOF");
 CREATE TABLE dbix_migration (
-    key CHAR(64) PRIMARY KEY,
+    name CHAR(64) PRIMARY KEY,
     value CHAR(64)
 );
 EOF
     $self->{_dbh}->do(<<"EOF");
-    INSERT INTO dbix_migration ( key, value ) VALUES ( 'version', '0' );
+    INSERT INTO dbix_migration ( name, value ) VALUES ( 'version', '0' );
 EOF
 }
 
@@ -188,12 +188,13 @@ sub _files {
     my ( $self, $type, $need ) = @_;
     my @files;
     for my $i (@$need) {
-        my @matches =
-          glob( File::Spec->catfile( $self->dir, "*${i}_$type.sql" ) );
-        for my $file (@matches) {
-            $file = File::Spec->rel2abs($file);
+        opendir(DIR, $self->dir) or die $!;
+        while (my $file = readdir(DIR)) {
+            next unless $file =~ /${i}_$type\.sql$/;
+            $file = File::Spec->catdir($self->dir, $file);
             push @files, { name => $file, version => $i };
         }
+        closedir(DIR);
     }
     return undef unless @$need == @files;
     return @files ? \@files : undef;
@@ -202,17 +203,22 @@ sub _files {
 sub _newest {
     my $self   = shift;
     my $newest = 0;
-    for my $up ( glob( File::Spec->catfile( $self->dir, "*_up.sql" ) ) ) {
-        $up =~ /\D*(\d+)_up.sql$/;
+
+    opendir(DIR, $self->dir) or die $!;
+    while (my $file = readdir(DIR)) {
+        next unless $file =~ /_up\.sql$/;
+        $file =~ /\D*(\d+)_up.sql$/;
         $newest = $1 if $1 > $newest;
     }
+    closedir(DIR);
+
     return $newest;
 }
 
 sub _update_migration_table {
     my ( $self, $version ) = @_;
     $self->{_dbh}->do(<<"EOF");
-UPDATE dbix_migration SET value = '$version' WHERE key = 'version';
+UPDATE dbix_migration SET value = '$version' WHERE name = 'version';
 EOF
 }
 
@@ -221,7 +227,7 @@ sub _version {
     my $version = undef;
     eval {
         my $sth = $self->{_dbh}->prepare(<<"EOF");
-SELECT value FROM dbix_migration WHERE key = ?;
+SELECT value FROM dbix_migration WHERE name = ?;
 EOF
         $sth->execute('version');
         for my $val ( $sth->fetchrow_arrayref ) {
